==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/be.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "be",
    "date_order": "DMY",
    "january": [
        "студзень",
        "сту",
        "студзеня",
        "Стд"
    ],
    "february": [
        "люты",
        "лют",
        "лютага"
    ],
    "march": [
        "сакавік",
        "сак",
        "сакавіка"
    ],
    "april": [
        "красавік",
        "кра",
        "красавіка",
        "Крс"
    ],
    "may": [
        "май",
        "мая",
        "Траўня",
        "Тра"
    ],
    "june": [
        "чэрвень",
        "чэр",
        "чэрвеня"
    ],
    "july": [
        "ліпень",
        "ліп",
        "ліпеня"
    ],
    "august": [
        "жнівень",
        "жні",
        "жніўня",
        "Жнівеня",
        "Жнв"
    ],
    "september": [
        "верасень",
        "вер",
        "верасня",
        "Врс"
    ],
    "october": [
        "кастрычнік",
        "кас",
        "кастрычніка",
        "Кст"
    ],
    "november": [
        "лістапад",
        "ліс",
        "лістапада",
        "Ліс"
    ],
    "december": [
        "снежань",
        "сне",
        "снежня",
        "Снж"
    ],
    "monday": [
        "панядзелак",
        "пн",
        "Пнд"
    ],
    "tuesday": [
        "аўторак",
        "аў",
        "Аўт"
    ],
    "wednesday": [
        "серада",
        "ср"
    ],
    "thursday": [
        "чацвер",
        "чц",
        "Чцв",
        "Чв"
    ],
    "friday": [
        "пятніца",
        "пт",
        "Пят"
    ],
    "saturday": [
        "субота",
        "сб",
        "Суб"
    ],
    "sunday": [
        "нядзеля",
        "нд",
        "Няд"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "год",
        "г",
        "гады",
        "года",
        "гадоў"
    ],
    "month": [
        "месяц",
        "мес",
        "месяца",
        "месяцы",
        "месяцаў"
    ],
    "week": [
        "тыд",
        "тыдзень",
        "тыдня",
        "тыдні",
        "тыдняў"
    ],
    "day": [
        "дзень",
        "д",
        "дні",
        "дзён",
        "дзен"
    ],
    "hour": [
        "гадзіна",
        "гадз",
        "гадзіны",
        "гадзіну",
        "гадзін"
    ],
    "minute": [
        "хвіліна",
        "хв",
        "хвілін",
        "хвіліны",
        "хвіліну",
        "хвіл"
    ],
    "second": [
        "секунда",
        "с",
        "секунды",
        "секунду",
        "секунд",
        "сек"
    ],
    "relative-type": {
        "1 year ago": [
            "у мінулым годзе"
        ],
        "0 year ago": [
            "у гэтым годзе"
        ],
        "in 1 year": [
            "у наступным годзе"
        ],
        "1 month ago": [
            "у мінулым месяцы"
        ],
        "0 month ago": [
            "у гэтым месяцы"
        ],
        "in 1 month": [
            "у наступным месяцы"
        ],
        "1 week ago": [
            "на мінулым тыдні"
        ],
        "0 week ago": [
            "на гэтым тыдні"
        ],
        "in 1 week": [
            "на наступным тыдні"
        ],
        "1 day ago": [
            "учора",
            "ўчора"
        ],
        "0 day ago": [
            "сёння",
            "сення"
        ],
        "in 1 day": [
            "заўтра"
        ],
        "0 hour ago": [
            "у гэту гадзіну"
        ],
        "0 minute ago": [
            "у гэту хвіліну"
        ],
        "0 second ago": [
            "цяпер"
        ],
        "2 day ago": [
            "пазаўчора"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "праз (\\d+) год",
            "праз (\\d+) года",
            "праз (\\d+) г"
        ],
        "\\1 year ago": [
            "(\\d+) год таму",
            "(\\d+) года таму",
            "(\\d+) г таму"
        ],
        "in \\1 month": [
            "праз (\\d+) месяц",
            "праз (\\d+) месяца",
            "праз (\\d+) мес"
        ],
        "\\1 month ago": [
            "(\\d+) месяц таму",
            "(\\d+) месяца таму",
            "(\\d+) мес таму"
        ],
        "in \\1 week": [
            "праз (\\d+) тыдзень",
            "праз (\\d+) тыдня",
            "праз (\\d+) тыд"
        ],
        "\\1 week ago": [
            "(\\d+) тыдзень таму",
            "(\\d+) тыдня таму",
            "(\\d+) тыд таму"
        ],
        "in \\1 day": [
            "праз (\\d+) дзень",
            "праз (\\d+) дня",
            "праз (\\d+) д"
        ],
        "\\1 day ago": [
            "(\\d+) дзень таму",
            "(\\d+) дня таму",
            "(\\d+) д таму"
        ],
        "in \\1 hour": [
            "праз (\\d+) гадзіну",
            "праз (\\d+) гадзіны",
            "праз (\\d+) гадз"
        ],
        "\\1 hour ago": [
            "(\\d+) гадзіну таму",
            "(\\d+) гадзіны таму",
            "(\\d+) гадз таму"
        ],
        "in \\1 minute": [
            "праз (\\d+) хвіліну",
            "праз (\\d+) хвіліны",
            "праз (\\d+) хв"
        ],
        "\\1 minute ago": [
            "(\\d+) хвіліну таму",
            "(\\d+) хвіліны таму",
            "(\\d+) хв таму"
        ],
        "in \\1 second": [
            "праз (\\d+) секунду",
            "праз (\\d+) секунды",
            "праз (\\d+) с"
        ],
        "\\1 second ago": [
            "(\\d+) секунду таму",
            "(\\d+) секунды таму",
            "(\\d+) с таму"
        ]
    },
    "locale_specific": {},
    "skip": [
        "каля",
        "у",
        "ў",
        "і",
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "таму назад",
        "таму",
        "назад"
    ],
    "in": [
        "на працягу"
    ],
    "simplifications": [
        {
            "^гадзіна": "1 гадзіна"
        },
        {
            "гадзіну": "1 гадзіну"
        },
        {
            "^хвіліну": "1 хвіліну"
        },
        {
            "^секунду": "1 секунду"
        },
        {
            "некалькі секунд": "44 секунды"
        },
        {
            "некалькі хвілін": "2 хвіліны"
        },
        {
            "(\\d+)\\s*гадзін\\s(\\d+)\\s*хвілін": "\\1:\\2"
        }
    ]
}

==> python-dateparser-1.1.0-3-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/be.py <==
info = {
    "name": "be",
    "date_order": "DMY",
    "january": [
        "сту",
        "студзень",
        "студзеня",
        "Стд"
    ],
    "february": [
        "лют",
        "лютага",
        "люты"
    ],
    "march": [
        "сак",
        "сакавік",
        "сакавіка"
    ],
    "april": [
        "кра",
        "красавік",
        "красавіка",
        "Крс"
    ],
    "may": [
        "май",
        "мая",
        "Траўня",
        "Тра"
    ],
    "june": [
        "чэр",
        "чэрвень",
        "чэрвеня"
    ],
    "july": [
        "ліп",
        "ліпень",
        "ліпеня"
    ],
    "august": [
        "жні",
        "жнівень",
        "жніўня",
        "Жнівеня",
        "Жнв"
    ],
    "september": [
        "вер",
        "верасень",
        "верасня",
        "Врс"
    ],
    "october": [
        "кас",
        "кастрычнік",
        "кастрычніка",
        "Кст"
    ],
    "november": [
        "ліс",
        "лістапад",
        "лістапада",
        "Ліс"
    ],
    "december": [
        "сне",
        "снежань",
        "снежня",
        "Снж"
    ],
    "monday": [
        "панядзелак",
        "пн",
        "Пнд"
    ],
    "tuesday": [
        "аў",
        "аўторак",
        "Аўт"
    ],
    "wednesday": [
        "серада",
        "ср"
    ],
    "thursday": [
        "чацвер",
        "чц",
        "Чцв",
        "Чв"
    ],
    "friday": [
        "пт",
        "пятніца",
        "Пят"
    ],
    "saturday": [
        "сб",
        "субота",
        "Суб"
    ],
    "sunday": [
        "нд",
        "нядзеля",
        "Няд"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "г",
        "год",
        "гады",
        "года",
        "гадоў"
    ],
    "month": [
        "мес",
        "месяц",
        "месяца",
        "месяцы",
        "месяцаў"
    ],
    "week": [
        "тыд",
        "тыдзень",
        "тыдня",
        "тыдні",
        "тыдняў"
    ],
    "day": [
        "д",
        "дзень",
        "дні",
        "дзён",
        "дзен"
    ],
    "hour": [
        "гадз",
        "гадзіна",
        "гадзіны",
        "гадзіну",
        "гадзін"
    ],
    "minute": [
        "хв",
        "хвіліна",
        "хвілін",
        "хвіліны",
        "хвіліну",
        "хвіл"
    ],
    "second": [
        "с",
        "секунда",
        "секунды",
        "секунду",
        "секунд",
        "сек"
    ],
    "relative-type": {
        "0 day ago": [
            "сёння",
            "сення"
        ],
        "0 hour ago": [
            "у гэту гадзіну"
        ],
        "0 minute ago": [
            "у гэту хвіліну"
        ],
        "0 month ago": [
            "у гэтым месяцы"
        ],
        "0 second ago": [
            "цяпер"
        ],
        "0 week ago": [
            "на гэтым тыдні"
        ],
        "0 year ago": [
            "у гэтым годзе"
        ],
        "1 day ago": [
            "учора",
            "ўчора"
        ],
        "1 month ago": [
            "у мінулым месяцы"
        ],
        "1 week ago": [
            "на мінулым тыдні"
        ],
        "1 year ago": [
            "у мінулым годзе"
        ],
        "in 1 day": [
            "заўтра"
        ],
        "in 1 month": [
            "у наступным месяцы"
        ],
        "in 1 week": [
            "на наступным тыдні"
        ],
        "in 1 year": [
            "у наступным годзе"
        ],
        "2 day ago": [
            "пазаўчора"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+) д таму",
            "(\\d+) дзень таму",
            "(\\d+) дня таму"
        ],
        "\\1 hour ago": [
            "(\\d+) гадз таму",
            "(\\d+) гадзіну таму",
            "(\\d+) гадзіны таму"
        ],
        "\\1 minute ago": [
            "(\\d+) хв таму",
            "(\\d+) хвіліну таму",
            "(\\d+) хвіліны таму"
        ],
        "\\1 month ago": [
            "(\\d+) мес таму",
            "(\\d+) месяц таму",
            "(\\d+) месяца таму"
        ],
        "\\1 second ago": [
            "(\\d+) с таму",
            "(\\d+) секунду таму",
            "(\\d+) секунды таму"
        ],
        "\\1 week ago": [
            "(\\d+) тыд таму",
            "(\\d+) тыдзень таму",
            "(\\d+) тыдня таму"
        ],
        "\\1 year ago": [
            "(\\d+) г таму",
            "(\\d+) год таму",
            "(\\d+) года таму"
        ],
        "in \\1 day": [
            "праз (\\d+) д",
            "праз (\\d+) дзень",
            "праз (\\d+) дня"
        ],
        "in \\1 hour": [
            "праз (\\d+) гадз",
            "праз (\\d+) гадзіну",
            "праз (\\d+) гадзіны"
        ],
        "in \\1 minute": [
            "праз (\\d+) хв",
            "праз (\\d+) хвіліну",
            "праз (\\d+) хвіліны"
        ],
        "in \\1 month": [
            "праз (\\d+) мес",
            "праз (\\d+) месяц",
            "праз (\\d+) месяца"
        ],
        "in \\1 second": [
            "праз (\\d+) с",
            "праз (\\d+) секунду",
            "праз (\\d+) секунды"
        ],
        "in \\1 week": [
            "праз (\\d+) тыд",
            "праз (\\d+) тыдзень",
            "праз (\\d+) тыдня"
        ],
        "in \\1 year": [
            "праз (\\d+) г",
            "праз (\\d+) год",
            "праз (\\d+) года"
        ]
    },
    "locale_specific": {},
    "skip": [
        "каля",
        "у",
        "і",
        "ў",
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ],
    "sentence_splitter_group": 1,
    "ago": [
        "таму назад",
        "таму",
        "назад"
    ],
    "in": [
        "на працягу"
    ],
    "simplifications": [
        {
            "^гадзіна": "1 гадзіна"
        },
        {
            "гадзіну": "1 гадзіну"
        },
        {
            "^хвіліну": "1 хвіліну"
        },
        {
            "^секунду": "1 секунду"
        },
        {
            "некалькі секунд": "44 секунды"
        },
        {
            "некалькі хвілін": "2 хвіліны"
        },
        {
            "(\\d+)\\s*гадзін\\s(\\d+)\\s*хвілін": "\\1:\\2"
        }
    ]
}
